@@ -13,7 +13,15 @@ from xarray.core import utils
 
 @xr.register_dataset_accessor("velocimetry")
 class Velocimetry(ORCBase):
+    """Velocimetry functionalities that can be applied on ``xarray.Dataset``"""
     def __init__(self, xarray_obj):
+        """Initialize a velocimetry ``xarray.Dataset``
+
+        Parameters
+        ----------
+        xarray_obj: xr.Dataset
+            velocimetry data fields (from ``pyorc.Frames.get_piv``)
+        """
         super(Velocimetry, self).__init__(xarray_obj)
 
     def filter_temporal(
@@ -32,22 +40,44 @@ class Velocimetry(ORCBase):
             kwargs_neighbour={},
             inplace=False
     ):
-        """
-        Masks values using several filters that use temporal variations or comparison as basis.
+        """Masks values using several filters that use temporal variations or comparison as basis.
+
+        Parameters
+        ----------
+        v_x : str, optional
+            name of x-directional velocity (default: "v_x")
+        v_y : str, optional
+            name of y-directional velocity (default: "v_y")
+        filter_std : boolean, optional
+            if True (default), filtering on variance is applied
+        filter_std : boolean, optional
+            if True (default), filtering on variance is applied
+        filter_angle : boolean, optional
+            if True (default), filtering on angles is applied
+        filter_velocity : boolean
+            if True (default, filtering on velocity is applied)
+        filter_corr : boolean
+            if True (default), filtering on correlation is applied
+        filter_neighbour : dict, optional
+            if True (default), neighbourhood filtering is applied
+        kwargs_std : dict, optional
+            set of key-word arguments to pass on to filter_temporal_std
+        kwargs_angle : dict, optional
+            set of key-word arguments to pass on to filter_temporal_angle
+        kwargs_velocity : dict, optional
+            set of key-word arguments to pass on to filter_temporal_velocity
+        kwargs_corr : dict, optional
+            set of key-word arguments to pass on to filter_temporal_corr
+        kwargs_neighbour : dict, optional
+            set of key-word arguments to pass on to filter_temporal_neighbour
+        inplace : boolean
+            If set, values are replaced instead of returning a new Dataset
+
+        Returns
+        -------
+        ds_filter : xr.Dataset
+            temporally filtered velocity vectors as [time, y, x]
 
-        :param ds: xr.Dataset, or file containing, with velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param filter_std: boolean, if True (default, filtering on variance is applied)
-        :param filter_std: boolean, if True (default, filtering on variance is applied)
-        :param filter_angle: boolean, if True (default, filtering on angles is applied)
-        :param filter_velocity: boolean, if True (default, filtering on velocity is applied)
-        :param filter_corr: boolean, if True (default, filtering on correlation is applied)
-        :param kwargs_std: dict, set of key-word arguments to pass on to filter_temporal_std
-        :param kwargs_angle: dict, set of key-word arguments to pass on to filter_temporal_angle
-        :param kwargs_velocity: dict, set of key-word arguments to pass on to filter_temporal_velocity
-        :param kwargs_corr: dict, set of key-word arguments to pass on to filter_temporal_corr
-        :return: xr.Dataset, containing temporally filtered velocity vectors as [time, y, x]
         """
         # load dataset in memory and update self
         ds = copy.deepcopy(self._obj.load())
@@ -77,22 +107,32 @@ class Velocimetry(ORCBase):
             angle_tolerance=0.25 * np.pi,
             filter_per_timestep=True,
     ):
-        """
-        filters on the expected angle. The function filters points entirely where the mean angle over time
+        """filters on the expected angle. The function filters points entirely where the mean angle over time
         deviates more than input parameter angle_bounds (in radians). The function also filters individual
         estimates in time, in case the user wants this (filter_per_timestep=True), in case the angle on
         a specific time step deviates more than the defined amount from the average.
         note: this function does not work appropriately, if the expected angle (+/- anglebounds) are within
         range of zero, as zero is the same as 2*pi. This exception may be resolved in the future if necessary.
 
-        :param ds: xr.Dataset, containing velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param angle_expected float, angle (0-2*pi), measured clock-wise from vertical upwards direction, expected
-            in the velocites, default: 0.5*np.pi (meaning from left to right)
-        :param angle_tolerance: float (0-2*pi) maximum deviation from expected angle allowed.
-        :param filter_per_timestep: if set to True, tolerances are also checked per individual time step
-        :return: xr.Dataset, containing angle filtered velocity vectors as [time, y, x], default: True
+        Parameters
+        ----------
+        v_x : str
+            name of x-directional velocity (Default value = "v_x")
+        v_y : str
+            name of y-directional velocity (Default value = "v_y")
+        angle_expected : float
+            angle (0-2*pi), measured clock-wise from vertical upwards direction, expected
+            in the velocities, default: 0.5*np.pi (meaning from left to right)
+        angle_tolerance : float (0-2*pi)
+            maximum deviation from expected angle allowed. (Default value = 0.25 * np.pi)
+        filter_per_timestep : boolean
+            if set to True (default), tolerances are also checked per individual time step
+
+        Returns
+        -------
+        ds_filter : xr.Dataset
+            angle filtered velocity vectors as [time, y, x]
+
         """
         # TODO: make function working appropriately, if angles are close to zero (2*pi)
         # first filter on the temporal mean. This is to ensure that widely varying results in angle are deemed not
@@ -110,16 +150,25 @@ class Velocimetry(ORCBase):
             self._obj[v_y] = self._obj[v_y].where(np.abs(angle - angle_expected) < angle_tolerance)
 
     def filter_temporal_neighbour(self, v_x="v_x", v_y="v_y", roll=5, tolerance=0.5):
-        """
-        Masks values if neighbours over a certain rolling length before and after, have a
+        """Masks values if neighbours over a certain rolling length before and after, have a
         significantly higher velocity than value under consideration, measured by tolerance.
 
-        :param ds: xr.Dataset, containing velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param roll: int, amount of time steps in rolling window (centred)
-        :param tolerance: float (0-1), Relative acceptable velocity of maximum found within rolling window
-        :return: xr.Dataset, containing time-neighbour filtered velocity vectors as [time, y, x]
+        Parameters
+        ----------
+        v_x : str, optional
+            name of x-directional velocity (Default: "v_x")
+        v_y : str, optional
+            name of y-directional velocity (Default: "v_y")
+        roll : int, optional
+            amount of time steps in rolling window (centred) (default: 5)
+        tolerance : float (0-1)
+            relative acceptable velocity of maximum found within rolling window (default: .5)
+
+        Returns
+        -------
+        type
+            xr.Dataset, containing time-neighbour filtered velocity vectors as [time, y, x]
+
         """
         s = (self._obj[v_x] ** 2 + self._obj[v_y] ** 2) ** 0.5
         s_roll = s.fillna(0.).rolling(time=roll, center=True).max()
@@ -129,14 +178,28 @@ class Velocimetry(ORCBase):
 
     def filter_temporal_std(
             self, v_x="v_x", v_y="v_y", tolerance_sample=1.0, tolerance_var=5., mode="or"):
-        """
-        Masks values if they deviate more than x standard deviations from the mean.
+        """Masks values if they deviate more than x standard deviations from the mean.
 
-        :param ds: xr.Dataset, containing velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param tolerance: float, representing amount of standard deviations
-        :return: xr.Dataset, containing standard deviation filtered velocity vectors as [time, y, x]
+        Parameters
+        ----------
+        v_x : str, optional
+            name of x-directional velocity (Default: "v_x")
+        v_y : str, optional
+            name of y-directional velocity (Default: "v_y")
+        tolerance :  float
+            amount of standard deviations tolerance
+        tolerance_sample :
+             (Default value = 1.0)
+        tolerance_var :
+             (Default value = 5.)
+        mode : str
+             can be "and" or "or" (default). If "or" ("and"), then only one (both) of two vector components need(s) to
+             be within tolerance.
+
+        Returns
+        -------
+        ds_filter : xr.Dataset
+            standard deviation filtered velocity vectors as [time, y, x]
         """
 
         # s = (self._obj[v_x] ** 2 + self._obj[v_y] ** 2) ** 0.5
@@ -170,21 +233,26 @@ class Velocimetry(ORCBase):
         self._obj[v_x] = self._obj[v_x].where(condition)
         self._obj[v_y] = self._obj[v_y].where(condition)
 
-        #
-        # self._obj[v_x] = self._obj[v_x].where((s - s_mean) / s_std < tolerance)
-        # self._obj[v_y] = self._obj[v_y].where((s - s_mean) / s_std < tolerance)
         # return ds
 
     def filter_temporal_velocity(self, v_x="v_x", v_y="v_y", s_min=0.1, s_max=5.0):
-        """
-        Masks values if the velocity scalar lies outside a user-defined valid range.
+        """Masks values if the velocity scalar lies outside a user-defined valid range.
 
-        :param ds: xr.Dataset, containing velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param s_min: float, minimum scalar velocity [m s-1]
-        :param s_max: float, maximum scalar velocity [m s-1]
-        :return: xr.Dataset, containing velocity-range filtered velocity vectors as [time, y, x]
+        Parameters
+        ----------
+        v_x : str, optional
+            name of x-directional velocity (Default: "v_x")
+        v_y : str, optional
+            name of y-directional velocity (Default: "v_y")
+        s_min : float, optional
+            minimum scalar velocity [m s-1] (default: 0.1)
+        s_max : float, optional
+            maximum scalar velocity [m s-1] (default: 5.)
+
+        Returns
+        -------
+        ds_filter : xr.Dataset
+            velocity-range filtered velocity vectors as [time, y, x]
         """
         s = (self._obj[v_x] ** 2 + self._obj[v_y] ** 2) ** 0.5
         self._obj[v_x] = self._obj[v_x].where(s > s_min)
@@ -200,15 +268,23 @@ class Velocimetry(ORCBase):
         # return ds
 
     def filter_temporal_corr(self, v_x="v_x", v_y="v_y", corr="corr", tolerance=0.1):
-        """
-        Masks values with a too low correlation.
+        """Masks values with a too low correlation.
 
-        :param ds: xr.Dataset, containing velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param corr: str, name of correlation variable
-        :param tolerance: float (0-1), tolerance for correlation value. If correlation is lower than tolerance, it is masked
-        :return: xr.Dataset, containing correlation filtered velocity vectors as [time, y, x]
+        Parameters
+        ----------
+        v_x : str, optional
+            name of x-directional velocity (Default: "v_x")
+        v_y : str, optional
+            name of y-directional velocity (Default: "v_y")
+        corr : str
+            name of correlation variable (default: "corr")
+        tolerance : float (0-1)
+            tolerance for correlation value (default: 0.1). If correlation is lower than tolerance, it is masked
+
+        Returns
+        -------
+        ds_filter : xr.Dataset
+            correlation filtered velocity vectors as [time, y, x]
         """
         self._obj[v_x] = self._obj[v_x].where(self._obj[corr] > tolerance)
         self._obj[v_y] = self._obj[v_y].where(self._obj[corr] > tolerance)
@@ -224,15 +300,30 @@ class Velocimetry(ORCBase):
             kwargs_median={},
             inplace=False
     ):
-        """
-        Masks velocity values on a number of spatial filters.
+        """Masks velocity values on a number of spatial filters.
+
+        Parameters
+        ----------
+        v_x : str, optional
+            name of x-directional velocity (default: "v_x")
+        v_y : str, optional
+            name of y-directional velocity (default: "v_y")
+        filter_nan : boolean, optional
+            if True (default), filtering on nans is applied
+        filter_median : boolean, optional
+            if True (default), filtering on median deviations is applied
+        kwargs_nan : dict, optional
+            dict, keyword arguments to pass to filter_spatial_nan
+        kwargs_median : dict, optional
+            keyword arguments to pass to filter_spatial_median
+        inplace : boolean, optional
+            If True (default: False), values are replaced instead of returning a new Dataset
+
+        Returns
+        -------
+        ds_filter : xr.Dataset
+            spatially filtered velocity vectors as [time, y, x]
 
-        :param self: xr.Dataset, or file containing, with velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param kwargs_nan: dict, keyword arguments to pass to filter_spatial_nan
-        :param kwargs_median: dict, keyword arguments to pass to filter_spatial_median
-        :return: xr.Dataset, containing spatially filtered velocity vectors as [time, y, x]
         """
         # work on v_x and v_y only
         ds_temp = self._obj[[v_x, v_y]].copy(deep=True).load()
@@ -248,23 +339,37 @@ class Velocimetry(ORCBase):
         else:
             return ds
 
-    def filter_spatial_nan(self, v_x="v_x", v_y="v_y", **kwargs):
-        """
-        Masks values if their surrounding neighbours (inc. value itself) contain too many NaN. Meant to remove isolated
+    def filter_spatial_nan(self, v_x="v_x", v_y="v_y", tolerance=0.3, wdw=1, missing=-9999.):
+        """Masks values if their surrounding neighbours (inc. value itself) contain too many NaN. Meant to remove isolated
         velocity estimates.
 
-        :param self: xr.Dataset, containing velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param tolerance: float, amount of NaNs in search window measured as a fraction of total amount of values [0-1]
-        :param stride: int, stride used to determine relevant neighbours
-        :param missing: float, a temporary missing value, used to be able to convolve NaNs
-        :return: xr.Dataset, containing NaN filtered velocity vectors as [time, y, x]
+        Parameters
+        ----------
+        v_x : str, optional
+            name of x-directional velocity (default: "v_x")
+        v_y : str, optional
+            name of y-directional velocity (default: "v_y")
+        tolerance : float, optional
+            amount of NaNs in search window measured as a fraction of total amount of values [0-1] (default: 0.3)
+        wdw : int, optional
+            window length used to determine relevant neighbours. 1 means that 1 neighbour on all sides is considered
+            (default: 1)
+        missing : float, optional
+            a temporary missing value, used to be able to convolve NaNs, normally not needed to change (default -9999.)
+
+        Returns
+        -------
+        ds_filter: xr.Dataset
+            NaN filtered velocity vectors as [time, y, x]
+
         """
-        def _filter_nan(ds_slice, v_x="v_x", v_y="v_y", tolerance=0.3, stride=1, missing=-9999.):
+        def _filter_nan(ds_slice, v_x="v_x", v_y="v_y", tolerance=0.3, wdw=1, missing=-9999.):
+            """
+            internal function, see main function
+            """
             # u, v = ds[v_x], ds[v_y]
             u, v = ds_slice[v_x].values, ds_slice[v_y].values
-            u_move = helpers.neighbour_stack(u.copy(), stride=stride, missing=missing)
+            u_move = helpers.neighbour_stack(u.copy(), stride=wdw, missing=missing)
             # replace missings by Nan
             nan_frac = np.float64(np.isnan(u_move)).sum(axis=0) / float(len(u_move))
             u[nan_frac > tolerance] = np.nan
@@ -274,27 +379,47 @@ class Velocimetry(ORCBase):
             return ds_slice
         ds_g = self._obj.groupby("time")
         self._obj.update(
-            ds_g.apply(_filter_nan, v_x=v_x, v_y=v_y, **kwargs)
+            ds_g.apply(
+                _filter_nan,
+                v_x=v_x,
+                v_y=v_y,
+                tolerance=tolerance,
+                wdw=wdw,
+                missing=missing
+            )
         )
 
-    def filter_spatial_median(self, v_x="v_x", v_y="v_y", **kwargs):
-        """
-        Masks values when their value deviates more than x standard deviations from the median of its neighbours
+    def filter_spatial_median(self, v_x="v_x", v_y="v_y", tolerance=0.7, wdw=1, missing=-9999.):
+        """Masks values when their value deviates more than x standard deviations from the median of its neighbours
         (inc. itself).
 
-        :param self: xr.Dataset, containing velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param tolerance: float, amount of standard deviations tolerance
-        :param stride: int, stride used to determine relevant neighbours
-        :param missing: float, a temporary missing value, used to be able to convolve NaNs
-        :return: xr.Dataset, containing std filtered velocity vectors as [time, y, x]
+        Parameters
+        ----------
+        v_x : str, optional
+            name of x-directional velocity (default: "v_x")
+        v_y : str, optional
+            name of y-directional velocity (default: "v_y")
+        tolerance : float, optional
+            amount of standard deviations tolerance (default: 0.7)
+        wdw : int, optional
+            window used to determine relevant neighbours
+        missing : float, optional
+            a temporary missing value, used to be able to convolve NaNs
+
+        Returns
+        -------
+        ds_filter : xr.Dataset
+            std filtered velocity vectors as [time, y, x]
+
         """
-        def _filter_median(ds_slice, v_x="v_x", v_y="v_y", tolerance=0.7, stride=1, missing=-9999.):
+        def _filter_median(ds_slice, v_x="v_x", v_y="v_y", tolerance=0.7, wdw=1, missing=-9999.):
+            """
+            internal function, see main method
+            """
             u, v = ds_slice[v_x].values, ds_slice[v_y].values
             # s = (u ** 2 + v ** 2) ** 0.5
-            u_move = helpers.neighbour_stack(copy.deepcopy(u), stride=stride, missing=missing)
-            v_move = helpers.neighbour_stack(copy.deepcopy(v), stride=stride, missing=missing)
+            u_move = helpers.neighbour_stack(copy.deepcopy(u), stride=wdw, missing=missing)
+            v_move = helpers.neighbour_stack(copy.deepcopy(v), stride=wdw, missing=missing)
             with warnings.catch_warnings():
                 warnings.simplefilter("ignore", category=RuntimeWarning)
 
@@ -312,7 +437,7 @@ class Velocimetry(ORCBase):
             return ds_slice
         ds_g = self._obj.groupby("time")
         self._obj.update(
-            ds_g.apply(_filter_median, v_x=v_x, v_y=v_y, **kwargs)
+            ds_g.apply(_filter_median, v_x=v_x, v_y=v_y, tolerance=tolerance, wdw=wdw, missing=missing)
         )
 
 
@@ -327,34 +452,44 @@ class Velocimetry(ORCBase):
             rolling=None,
             quantiles=[0.05, 0.25, 0.5, 0.75, 0.95]
     ):
-        """
-        Interpolate all variables to supplied x and y coordinates of a cross section. This function assumes that the
+        """Interpolate all variables to supplied x and y coordinates of a cross section. This function assumes that the
         grid can be rotated and that xs and ys are supplied following the projected coordinates supplied in
         "xs" and "ys" coordinate variables in ds. x-coordinates and y-coordinates that fall outside the
         domain of ds, are still stored in the result for further interpolation or extrapolation.
         Original coordinate values supplied are stored in coordinates "x", "y" and (if supplied) "z".
         Time series are transformed to set quantiles.
 
-        :param self: xarray dataset
-        :param x: tuple or list-like, x-coordinates on which interpolation should be done
-        :param y: tuple or list-like, y-coordinates on which interpolation should be done
-        :param z: tuple or list-like, z-coordinates on which interpolation should be done, defaults: None
-        :param crs: coordinate reference system (e.g. EPSG code) in which x, y and z are measured, defaults to None,
-            assuming crs is the same as crs of ds
-        :param v_eff: bool, if True, effective velocity (perpendicular to cross-section) is also computed, default: True
-        :param xs: str, name of variable that stores the x coordinates in the projection in which "x" is supplied,
-            default: "xs"
-        :param ys: str, name of variable that stores the y coordinates in the projection in which "y" is supplied
-            default: "ys"
-        :param distance: float, optional, sampling distance over the cross-section in [m]. the bathymetry points will
-            be interpolated to match this distance. If not set, the distance will be estimated from the velocimetry
-            grid resolution.
-        :param wdw: int, window size to use for sampling the velocity. zero means, only cell itself, 1 means 3x3 window.
-        :param rolling: int, optional, if set, a rolling mean over time is applied, before deriving quantile estimates.
-        :param quantiles: list of floats (0-1), optional, list of quantiles to return
-            (default: [0.05, 0.25, 0.5, 0.75, 0.95]).
-        :return: ds_points: xarray dataset, containing interpolated data at the supplied x and y coordinates over
-            quantiles.
+        Parameters
+        ----------
+        x : tuple or list-like
+            x-coordinates on which interpolation should be done
+        y : tuple or list-like
+            y-coordinates on which interpolation should be done
+        z : tuple or list-like
+            z-coordinates on which interpolation should be done, defaults: None
+        crs : int, dict or str, optional
+            coordinate reference system (e.g. EPSG code) in which x, y and z are measured (default: None),
+            None assumes crs is the same as crs of xr.Dataset.
+        v_eff : boolean, optional
+            if True (default), effective velocity (perpendicular to cross-section) is also computed
+        xs : str, optional
+            name of variable that stores the x coordinates in the projection in which "x" is supplied (default: "xs")
+        ys : str, optional
+            name of variable that stores the y coordinates in the projection in which "y" is supplied (default: "ys")
+        distance : float, optional
+            sampling distance over the cross-section in [m]. the bathymetry points will be interpolated to match this
+            distance. If not set, the distance will be estimated from the velocimetry grid resolution. (default: None)
+        wdw : int, window size to use for sampling the velocity. zero means, only cell itself, 1 means 3x3 window.
+            (default: 1)
+        rolling : int, optional
+            if set other than None (default), a rolling mean over time is applied, before deriving quantile estimates.
+        quantiles : list of floats (0-1), optional
+            list of quantiles to return (default: [0.05, 0.25, 0.5, 0.75, 0.95]).
+
+        Returns
+        -------
+        ds_points: xr.Dataset
+            interpolated data at the supplied x and y coordinates over quantiles
         """
         transform = helpers.affine_from_grid(self._obj[xs].values, self._obj[ys].values)
         if crs is not None:
@@ -435,38 +570,49 @@ class Velocimetry(ORCBase):
     # add .plot as group of methods, UncachedAccessor ensures that Velocimetry is passed as object
     plot = utils.UncachedAccessor(_Velocimetry_PlotMethods)
 
-    def replace_outliers(self, v_x="v_x", v_y="v_y", stride=1, max_iter=1, inplace=False):
-        """
-        Replace missing values using neighbourhood operators. Use this with caution as it creates data. If many samples
+    def replace_outliers(self, v_x="v_x", v_y="v_y", wdw=1, max_iter=1, inplace=False):
+        """Replace missing values using neighbourhood operators. Use this with caution as it creates data. If many samples
         in time are available to derive a mean or median velocity from, consider using a reducer on those samples
         instead of a spatial infilling method such as suggested here.
 
-        :param self: xarray Dataset, containing velocity vectors as [time, y, x]
-        :param v_x: str, name of x-directional velocity
-        :param v_y: str, name of y-directional velocity
-        :param stride: int, stride used to determine relevant neighbours
-        :param max_iter: number of iterations for replacement
-        :return: xr.Dataset, containing filtered velocities
+        Parameters
+        ----------
+        v_x : str, optional
+            name of x-directional velocity (default: "v_x")
+        v_y : str, optional
+            name of y-directional velocity (default: "v_y")
+        wdw : int, optional
+            window size used to determine relevant neighbours (default: 1), 1 means a 3x3 window (1 neighbour)
+        max_iter : int, optional
+            number of iterations for replacement (default: 1)
+        inplace : boolean, optional
+            replace values instead of returning new xr.Dataset (default: False)
+
+        Returns
+        -------
+        ds_replaced : xr.Dataset
+            velocities with replacements [time, x, y]
+
         """
         # TO-DO: make replacement decision dependent on amount of non-NaN values in neighbourhood
-        u, v = self._obj[v_x].values, self._obj[v_y].values
+        u, v = copy.deepcopy(self._obj[v_x].values), copy.deepcopy(self._obj[v_y].values)
         for n in range(max_iter):
-            u_move = helpers.neighbour_stack(u, stride=stride)
-            v_move = helpers.neighbour_stack(v, stride=stride)
+            u_move = helpers.neighbour_stack(u, stride=wdw)
+            v_move = helpers.neighbour_stack(v, stride=wdw)
             # compute mean
             u_mean = np.nanmean(u_move, axis=0)
             v_mean = np.nanmean(v_move, axis=0)
             u[np.isnan(u)] = u_mean[np.isnan(u)]
             v[np.isnan(v)] = v_mean[np.isnan(v)]
             # all values with stride distance from edge have to be made NaN
-            u[0:stride, :] = np.nan;
-            u[-stride:, :] = np.nan;
-            u[:, 0:stride] = np.nan;
-            u[:, -stride:] = np.nan
-            v[0:stride, :] = np.nan;
-            v[-stride:, :] = np.nan;
-            v[:, 0:stride] = np.nan;
-            v[:, -stride:] = np.nan
+            u[0:wdw, :] = np.nan;
+            u[-wdw:, :] = np.nan;
+            u[:, 0:wdw] = np.nan;
+            u[:, -wdw:] = np.nan
+            v[0:wdw, :] = np.nan;
+            v[-wdw:, :] = np.nan;
+            v[:, 0:wdw] = np.nan;
+            v[:, -wdw:] = np.nan
         if inplace:
             self._obj[v_x][:] = u
             self._obj[v_y][:] = v
@@ -476,6 +622,19 @@ class Velocimetry(ORCBase):
             ds[v_y][:] = v
             return ds
 
-    def set_encoding(self):
+    def set_encoding(self, enc_pars=const.ENCODING_PARAMS):
+        """Set encoding parameters for all typical variables in a velocimetry dataset. This reduces the required storage
+        for this dataset significantly, when stored to disk in e.g. a netcdf file using ``xarray.Dataset.to_netcdf``.
+
+        Parameters
+        ----------
+        enc_pars : dict of dicts, optional
+            per variable, a dict containing encoding parameters. When called without input, a standard set of encoding
+            parameters is used that compresses well. (Default value = const.ENCODING_PARAMS)
+
+        Returns
+        -------
+
+        """
         for k in const.ENCODE_VARS:
-            self._obj[k].encoding = const.ENCODING_PARAMS
+            self._obj[k].encoding = enc_pars
